//
//  NSDate+NTPTimestamp.h
//
//  Created by Roman Kolesnichenko on 07.08.15.
//  Refactored from Gavin Eadie ios-ntp https://github.com/jbenet/ios-ntp


#import <Foundation/Foundation.h>

//   RFC 5905             NTPv4 Specification                June 2010
//   http://www.ietf.org/rfc/rfc5905.txt

/*   NTP Timestamp Format
 
 0                   1                   2                   3
 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                            Seconds                            |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |                            Fraction                           |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 */

struct NTPTimestampStruct
{
    uint32_t seconds;
    uint32_t fraction;
};
typedef struct NTPTimestampStruct NTPTimestamp;


/*   NTP Short Format
 
 0                   1                   2                   3
 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 |          Seconds              |           Fraction            |
 +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 
 */

struct NTPTimestampShortStruct
{
    uint16_t seconds;
    uint16_t fraction;
};
typedef struct NTPTimestampShortStruct NTPTimestampShort;


@interface NSDate (NTPTimestamp)

+ (instancetype)dateWithNTPTimestamp:(NTPTimestamp)timestamp;

@property (nonatomic, readonly) NTPTimestamp NTPTimestamp;

@end
